# Generated by ariadne-codegen on 2023-07-13 16:02
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionPreviewFragment


class EstimateSubscriptionUpdate(BaseModel):
    estimate_subscription_update: "EstimateSubscriptionUpdateEstimateSubscriptionUpdate" = Field(
        alias="estimateSubscriptionUpdate"
    )


class EstimateSubscriptionUpdateEstimateSubscriptionUpdate(SubscriptionPreviewFragment):
    pass


EstimateSubscriptionUpdate.update_forward_refs()
EstimateSubscriptionUpdateEstimateSubscriptionUpdate.update_forward_refs()
